Title: [156339] trunk/Source/WebCore
Revision
156339
Author
commit-qu...@webkit.org
Date
2013-09-24 10:57:25 -0700 (Tue, 24 Sep 2013)

Log Message

AX: Replace AXObjectCache postNotification method boolean arguments with enum values.
https://bugs.webkit.org/show_bug.cgi?id=121504

Patch by Samuel White <samuel_wh...@apple.com> on 2013-09-24
Reviewed by Chris Fleizach.

No new tests, no functional changes. Changed argument type from bool
to enum per "Names" rule #10 in the WebKit coding style guidelines.

* accessibility/AXObjectCache.cpp:
(WebCore::AXObjectCache::textChanged):
(WebCore::AXObjectCache::postNotification):
(WebCore::AXObjectCache::checkedStateChanged):
(WebCore::AXObjectCache::selectedChildrenChanged):
(WebCore::AXObjectCache::handleAttributeChanged):
* accessibility/AXObjectCache.h:
(WebCore::AXObjectCache::postNotification):
* accessibility/AccessibilityMenuList.cpp:
(WebCore::AccessibilityMenuList::didUpdateActiveOption):
* accessibility/AccessibilityMenuListPopup.cpp:
(WebCore::AccessibilityMenuListPopup::didUpdateActiveOption):
* accessibility/AccessibilityNodeObject.cpp:
(WebCore::AccessibilityNodeObject::childrenChanged):
(WebCore::AccessibilityNodeObject::changeValueByStep):
(WebCore::AccessibilityNodeObject::changeValueByPercent):
* accessibility/AccessibilityRenderObject.cpp:
(WebCore::AccessibilityRenderObject::handleAriaExpandedChanged):
(WebCore::AccessibilityRenderObject::handleActiveDescendantChanged):
(WebCore::AccessibilityRenderObject::textChanged):
* dom/Document.cpp:
(WebCore::Document::implicitClose):
* editing/Editor.cpp:
(WebCore::Editor::respondToChangedContents):
(WebCore::Editor::markAndReplaceFor):
* editing/mac/FrameSelectionMac.mm:
(WebCore::FrameSelection::notifyAccessibilityForSelectionChange):
* html/HTMLTextFormControlElement.cpp:
(WebCore::HTMLTextFormControlElement::setInnerTextValue):
* html/InputType.cpp:
(WebCore::InputType::applyStep):
* html/RangeInputType.cpp:
(WebCore::RangeInputType::handleKeydownEvent):
* page/FocusController.cpp:
(WebCore::FocusController::setInitialFocus):
* page/FrameView.cpp:
(WebCore::FrameView::layout):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (156338 => 156339)


--- trunk/Source/WebCore/ChangeLog	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/ChangeLog	2013-09-24 17:57:25 UTC (rev 156339)
@@ -1,3 +1,51 @@
+2013-09-24  Samuel White  <samuel_wh...@apple.com>
+
+        AX: Replace AXObjectCache postNotification method boolean arguments with enum values.
+        https://bugs.webkit.org/show_bug.cgi?id=121504
+
+        Reviewed by Chris Fleizach.
+
+        No new tests, no functional changes. Changed argument type from bool
+        to enum per "Names" rule #10 in the WebKit coding style guidelines.
+
+        * accessibility/AXObjectCache.cpp:
+        (WebCore::AXObjectCache::textChanged):
+        (WebCore::AXObjectCache::postNotification):
+        (WebCore::AXObjectCache::checkedStateChanged):
+        (WebCore::AXObjectCache::selectedChildrenChanged):
+        (WebCore::AXObjectCache::handleAttributeChanged):
+        * accessibility/AXObjectCache.h:
+        (WebCore::AXObjectCache::postNotification):
+        * accessibility/AccessibilityMenuList.cpp:
+        (WebCore::AccessibilityMenuList::didUpdateActiveOption):
+        * accessibility/AccessibilityMenuListPopup.cpp:
+        (WebCore::AccessibilityMenuListPopup::didUpdateActiveOption):
+        * accessibility/AccessibilityNodeObject.cpp:
+        (WebCore::AccessibilityNodeObject::childrenChanged):
+        (WebCore::AccessibilityNodeObject::changeValueByStep):
+        (WebCore::AccessibilityNodeObject::changeValueByPercent):
+        * accessibility/AccessibilityRenderObject.cpp:
+        (WebCore::AccessibilityRenderObject::handleAriaExpandedChanged):
+        (WebCore::AccessibilityRenderObject::handleActiveDescendantChanged):
+        (WebCore::AccessibilityRenderObject::textChanged):
+        * dom/Document.cpp:
+        (WebCore::Document::implicitClose):
+        * editing/Editor.cpp:
+        (WebCore::Editor::respondToChangedContents):
+        (WebCore::Editor::markAndReplaceFor):
+        * editing/mac/FrameSelectionMac.mm:
+        (WebCore::FrameSelection::notifyAccessibilityForSelectionChange):
+        * html/HTMLTextFormControlElement.cpp:
+        (WebCore::HTMLTextFormControlElement::setInnerTextValue):
+        * html/InputType.cpp:
+        (WebCore::InputType::applyStep):
+        * html/RangeInputType.cpp:
+        (WebCore::RangeInputType::handleKeydownEvent):
+        * page/FocusController.cpp:
+        (WebCore::FocusController::setInitialFocus):
+        * page/FrameView.cpp:
+        (WebCore::FrameView::layout):
+
 2013-09-24  Andreas Kling  <akl...@apple.com>
 
         Make hoverAncestor() a RenderElement concept.

Modified: trunk/Source/WebCore/accessibility/AXObjectCache.cpp (156338 => 156339)


--- trunk/Source/WebCore/accessibility/AXObjectCache.h	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/accessibility/AXObjectCache.h	2013-09-24 17:57:25 UTC (rev 156339)
@@ -71,6 +71,8 @@
     HashMap<AXID, CachedAXObjectAttributes> m_idMapping;
 };
 
+enum PostTarget { TargetElement, TargetObservableParent };
+
 enum PostType { PostSynchronously, PostAsynchronously };
 
 class AXObjectCache {
@@ -179,9 +181,9 @@
         AXAriaAttributeChanged
     };
 
-    void postNotification(RenderObject*, AXNotification, bool postToElement, PostType = PostAsynchronously);
-    void postNotification(Node*, AXNotification, bool postToElement, PostType = PostAsynchronously);
-    void postNotification(AccessibilityObject*, Document*, AXNotification, bool postToElement, PostType = PostAsynchronously);
+    void postNotification(RenderObject*, AXNotification, PostTarget = TargetElement, PostType = PostAsynchronously);
+    void postNotification(Node*, AXNotification, PostTarget = TargetElement, PostType = PostAsynchronously);
+    void postNotification(AccessibilityObject*, Document*, AXNotification, PostTarget = TargetElement, PostType = PostAsynchronously);
 
     enum AXTextChange {
         AXTextInserted,
@@ -298,9 +300,9 @@
 inline void AXObjectCache::handleScrolledToAnchor(const Node*) { }
 inline void AXObjectCache::nodeTextChangeNotification(Node*, AXTextChange, unsigned, const String&) { }
 inline void AXObjectCache::nodeTextChangePlatformNotification(AccessibilityObject*, AXTextChange, unsigned, const String&) { }
-inline void AXObjectCache::postNotification(AccessibilityObject*, Document*, AXNotification, bool, PostType) { }
-inline void AXObjectCache::postNotification(RenderObject*, AXNotification, bool, PostType) { }
-inline void AXObjectCache::postNotification(Node*, AXNotification, bool, PostType) { }
+inline void AXObjectCache::postNotification(AccessibilityObject*, Document*, AXNotification, PostTarget, PostType) { }
+inline void AXObjectCache::postNotification(RenderObject*, AXNotification, PostTarget, PostType) { }
+inline void AXObjectCache::postNotification(Node*, AXNotification, PostTarget, PostType) { }
 inline void AXObjectCache::postPlatformNotification(AccessibilityObject*, AXNotification) { }
 inline void AXObjectCache::remove(AXID) { }
 inline void AXObjectCache::remove(RenderObject*) { }

Modified: trunk/Source/WebCore/accessibility/AccessibilityMenuList.cpp (156338 => 156339)


--- trunk/Source/WebCore/accessibility/AccessibilityMenuList.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/accessibility/AccessibilityMenuList.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -119,7 +119,7 @@
         }
     }
 
-    cache->postNotification(this, document.get(), AXObjectCache::AXMenuListValueChanged, true, PostSynchronously);
+    cache->postNotification(this, document.get(), AXObjectCache::AXMenuListValueChanged, TargetElement, PostSynchronously);
 }
 
 } // namespace WebCore

Modified: trunk/Source/WebCore/accessibility/AccessibilityMenuListPopup.cpp (156338 => 156339)


--- trunk/Source/WebCore/accessibility/AccessibilityMenuListPopup.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/accessibility/AccessibilityMenuListPopup.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -137,8 +137,8 @@
     AXObjectCache* cache = axObjectCache();
     RefPtr<AccessibilityObject> child = m_children[optionIndex].get();
 
-    cache->postNotification(child.get(), document(), AXObjectCache::AXFocusedUIElementChanged, true, PostSynchronously);
-    cache->postNotification(child.get(), document(), AXObjectCache::AXMenuListItemSelected, true, PostSynchronously);
+    cache->postNotification(child.get(), document(), AXObjectCache::AXFocusedUIElementChanged, TargetElement, PostSynchronously);
+    cache->postNotification(child.get(), document(), AXObjectCache::AXMenuListItemSelected, TargetElement, PostSynchronously);
 }
 
 } // namespace WebCore

Modified: trunk/Source/WebCore/accessibility/AccessibilityNodeObject.cpp (156338 => 156339)


--- trunk/Source/WebCore/accessibility/AccessibilityNodeObject.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/accessibility/AccessibilityNodeObject.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -131,7 +131,7 @@
     if (!node() && !renderer())
         return;
 
-    axObjectCache()->postNotification(this, document(), AXObjectCache::AXChildrenChanged, true);
+    axObjectCache()->postNotification(this, document(), AXObjectCache::AXChildrenChanged);
 
     // Go up the accessibility parent chain, but only if the element already exists. This method is
     // called during render layouts, minimal work should be done. 
@@ -145,11 +145,11 @@
 
         // If this element supports ARIA live regions, then notify the AT of changes.
         if (parent->supportsARIALiveRegion())
-            axObjectCache()->postNotification(parent, parent->document(), AXObjectCache::AXLiveRegionChanged, true);
+            axObjectCache()->postNotification(parent, parent->document(), AXObjectCache::AXLiveRegionChanged);
         
         // If this element is an ARIA text control, notify the AT of changes.
         if (parent->isARIATextControl() && !parent->isNativeTextControl() && !parent->node()->rendererIsEditable())
-            axObjectCache()->postNotification(parent, parent->document(), AXObjectCache::AXValueChanged, true);
+            axObjectCache()->postNotification(parent, parent->document(), AXObjectCache::AXValueChanged);
     }
 }
 
@@ -1054,7 +1054,7 @@
 
     setValue(String::number(value));
 
-    axObjectCache()->postNotification(node(), AXObjectCache::AXValueChanged, true);
+    axObjectCache()->postNotification(node(), AXObjectCache::AXValueChanged);
 }
 
 void AccessibilityNodeObject::changeValueByPercent(float percentChange)
@@ -1065,7 +1065,7 @@
     value += range * (percentChange / 100);
     setValue(String::number(value));
 
-    axObjectCache()->postNotification(node(), AXObjectCache::AXValueChanged, true);
+    axObjectCache()->postNotification(node(), AXObjectCache::AXValueChanged);
 }
 
 bool AccessibilityNodeObject::isGenericFocusableElement() const

Modified: trunk/Source/WebCore/accessibility/AccessibilityRenderObject.cpp (156338 => 156339)


--- trunk/Source/WebCore/accessibility/AccessibilityRenderObject.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/accessibility/AccessibilityRenderObject.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -2301,11 +2301,11 @@
     
     // Post that the row count changed.
     if (containerParent)
-        axObjectCache()->postNotification(containerParent, document(), AXObjectCache::AXRowCountChanged, true);
+        axObjectCache()->postNotification(containerParent, document(), AXObjectCache::AXRowCountChanged);
 
     // Post that the specific row either collapsed or expanded.
     if (roleValue() == RowRole || roleValue() == TreeItemRole)
-        axObjectCache()->postNotification(this, document(), isExpanded() ? AXObjectCache::AXRowExpanded : AXObjectCache::AXRowCollapsed, true);
+        axObjectCache()->postNotification(this, document(), isExpanded() ? AXObjectCache::AXRowExpanded : AXObjectCache::AXRowCollapsed);
 }
 
 void AccessibilityRenderObject::handleActiveDescendantChanged()
@@ -2318,7 +2318,7 @@
     AccessibilityRenderObject* activedescendant = static_cast<AccessibilityRenderObject*>(activeDescendant());
     
     if (activedescendant && shouldNotifyActiveDescendant())
-        renderer()->document().axObjectCache()->postNotification(m_renderer, AXObjectCache::AXActiveDescendantChanged, true);
+        renderer()->document().axObjectCache()->postNotification(m_renderer, AXObjectCache::AXActiveDescendantChanged);
 }
 
 AccessibilityObject* AccessibilityRenderObject::correspondingControlForLabelElement() const
@@ -2711,10 +2711,10 @@
             continue;
         
         if (parent->supportsARIALiveRegion())
-            cache->postNotification(renderParent, AXObjectCache::AXLiveRegionChanged, true);
+            cache->postNotification(renderParent, AXObjectCache::AXLiveRegionChanged);
 
         if (parent->isARIATextControl() && !parent->isNativeTextControl() && !parent->node()->rendererIsEditable())
-            cache->postNotification(renderParent, AXObjectCache::AXValueChanged, true);
+            cache->postNotification(renderParent, AXObjectCache::AXValueChanged);
     }
 }
 

Modified: trunk/Source/WebCore/dom/Document.cpp (156338 => 156339)


--- trunk/Source/WebCore/dom/Document.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/dom/Document.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -2492,11 +2492,11 @@
         // only safe to call when a layout is not in progress, so it can not be used in postNotification.    
         axObjectCache()->getOrCreate(renderView());
         if (this == topDocument())
-            axObjectCache()->postNotification(renderView(), AXObjectCache::AXLoadComplete, true);
+            axObjectCache()->postNotification(renderView(), AXObjectCache::AXLoadComplete);
         else {
             // AXLoadComplete can only be posted on the top document, so if it's a document
             // in an iframe that just finished loading, post AXLayoutComplete instead.
-            axObjectCache()->postNotification(renderView(), AXObjectCache::AXLayoutComplete, true);
+            axObjectCache()->postNotification(renderView(), AXObjectCache::AXLayoutComplete);
         }
     }
 #endif

Modified: trunk/Source/WebCore/editing/Editor.cpp (156338 => 156339)


--- trunk/Source/WebCore/editing/Editor.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/editing/Editor.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -557,7 +557,7 @@
     if (AXObjectCache::accessibilityEnabled()) {
         Node* node = endingSelection.start().deprecatedNode();
         if (AXObjectCache* cache = m_frame.document()->existingAXObjectCache())
-            cache->postNotification(node, AXObjectCache::AXValueChanged, false);
+            cache->postNotification(node, AXObjectCache::AXValueChanged, TargetObservableParent);
     }
 
     updateMarkersForWordsAffectedByEditing(true);
@@ -2343,7 +2343,7 @@
 
                 if (AXObjectCache* cache = m_frame.document()->existingAXObjectCache()) {
                     if (Element* root = m_frame.selection().selection().rootEditableElement())
-                        cache->postNotification(root, AXObjectCache::AXAutocorrectionOccured, true);
+                        cache->postNotification(root, AXObjectCache::AXAutocorrectionOccured);
                 }
 
                 // Skip all other results for the replaced text.

Modified: trunk/Source/WebCore/editing/mac/FrameSelectionMac.mm (156338 => 156339)


--- trunk/Source/WebCore/editing/mac/FrameSelectionMac.mm	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/editing/mac/FrameSelectionMac.mm	2013-09-24 17:57:25 UTC (rev 156339)
@@ -51,7 +51,7 @@
 
     if (m_selection.start().isNotNull() && m_selection.end().isNotNull()) {
         if (AXObjectCache* cache = document->existingAXObjectCache())
-            cache->postNotification(m_selection.start().deprecatedNode()->renderer(), AXObjectCache::AXSelectedTextChanged, false);
+            cache->postNotification(m_selection.start().deprecatedNode()->renderer(), AXObjectCache::AXSelectedTextChanged, TargetObservableParent);
     }
 
     // if zoom feature is enabled, insertion point changes should update the zoom

Modified: trunk/Source/WebCore/html/HTMLTextFormControlElement.cpp (156338 => 156339)


--- trunk/Source/WebCore/html/HTMLTextFormControlElement.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/html/HTMLTextFormControlElement.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -505,7 +505,7 @@
     if (textIsChanged || !innerTextElement()->hasChildNodes()) {
         if (textIsChanged && renderer()) {
             if (AXObjectCache* cache = document().existingAXObjectCache())
-                cache->postNotification(this, AXObjectCache::AXValueChanged, false);
+                cache->postNotification(this, AXObjectCache::AXValueChanged, TargetObservableParent);
         }
         innerTextElement()->setInnerText(value, ASSERT_NO_EXCEPTION);
 

Modified: trunk/Source/WebCore/html/InputType.cpp (156338 => 156339)


--- trunk/Source/WebCore/html/InputType.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/html/InputType.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -1004,7 +1004,7 @@
     setValueAsDecimal(newValue, eventBehavior, ec);
 
     if (AXObjectCache* cache = element().document().existingAXObjectCache())
-        cache->postNotification(&element(), AXObjectCache::AXValueChanged, true);
+        cache->postNotification(&element(), AXObjectCache::AXValueChanged);
 }
 
 bool InputType::getAllowedValueStep(Decimal* step) const

Modified: trunk/Source/WebCore/html/RangeInputType.cpp (156338 => 156339)


--- trunk/Source/WebCore/html/RangeInputType.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/html/RangeInputType.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -245,7 +245,7 @@
         setValueAsDecimal(newValue, eventBehavior, IGNORE_EXCEPTION);
 
         if (AXObjectCache* cache = element().document().existingAXObjectCache())
-            cache->postNotification(&element(), AXObjectCache::AXValueChanged, true);
+            cache->postNotification(&element(), AXObjectCache::AXValueChanged);
         element().dispatchFormControlChangeEvent();
     }
 

Modified: trunk/Source/WebCore/page/FocusController.cpp (156338 => 156339)


--- trunk/Source/WebCore/page/FocusController.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/page/FocusController.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -252,7 +252,7 @@
     // into the web area again, even if focus did not change within WebCore. PostNotification is called instead
     // of handleFocusedUIElementChanged, because this will send the notification even if the element is the same.
     if (AXObjectCache* cache = focusedOrMainFrame().document()->existingAXObjectCache())
-        cache->postNotification(focusedOrMainFrame().document(), AXObjectCache::AXFocusedUIElementChanged, true);
+        cache->postNotification(focusedOrMainFrame().document(), AXObjectCache::AXFocusedUIElementChanged);
 
     return didAdvanceFocus;
 }

Modified: trunk/Source/WebCore/page/FrameView.cpp (156338 => 156339)


--- trunk/Source/WebCore/page/FrameView.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/page/FrameView.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -1327,7 +1327,7 @@
 
 #if PLATFORM(MAC) || PLATFORM(WIN) || PLATFORM(GTK)
     if (AXObjectCache* cache = root->document().existingAXObjectCache())
-        cache->postNotification(root, AXObjectCache::AXLayoutComplete, true);
+        cache->postNotification(root, AXObjectCache::AXLayoutComplete);
 #endif
 
 #if ENABLE(DASHBOARD_SUPPORT) || ENABLE(DRAGGABLE_REGION)
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebCore/accessibility/AXObjectCache.cpp	2013-09-24 17:51:16 UTC (rev 156338)
+++ trunk/Source/WebCore/accessibility/AXObjectCache.cpp	2013-09-24 17:57:25 UTC (rev 156339)
@@ -608,7 +608,7 @@
 
     bool parentAlreadyExists = obj->parentObjectIfExists();
     obj->textChanged();
-    postNotification(obj, obj->document(), AXObjectCache::AXTextChanged, true);
+    postNotification(obj, obj->document(), AXObjectCache::AXTextChanged);
     if (parentAlreadyExists)
         obj->notifyIfIgnoredValueChanged();
 }
@@ -674,7 +674,7 @@
     m_notificationsToPost.clear();
 }
     
-void AXObjectCache::postNotification(RenderObject* renderer, AXNotification notification, bool postToElement, PostType postType)
+void AXObjectCache::postNotification(RenderObject* renderer, AXNotification notification, PostTarget postTarget, PostType postType)
 {
     if (!renderer)
         return;
@@ -692,10 +692,10 @@
     if (!renderer)
         return;
     
-    postNotification(object.get(), &renderer->document(), notification, postToElement, postType);
+    postNotification(object.get(), &renderer->document(), notification, postTarget, postType);
 }
 
-void AXObjectCache::postNotification(Node* node, AXNotification notification, bool postToElement, PostType postType)
+void AXObjectCache::postNotification(Node* node, AXNotification notification, PostTarget postTarget, PostType postType)
 {
     if (!node)
         return;
@@ -713,14 +713,14 @@
     if (!node)
         return;
     
-    postNotification(object.get(), &node->document(), notification, postToElement, postType);
+    postNotification(object.get(), &node->document(), notification, postTarget, postType);
 }
 
-void AXObjectCache::postNotification(AccessibilityObject* object, Document* document, AXNotification notification, bool postToElement, PostType postType)
+void AXObjectCache::postNotification(AccessibilityObject* object, Document* document, AXNotification notification, PostTarget postTarget, PostType postType)
 {
     stopCachingComputedObjectAttributes();
 
-    if (object && !postToElement)
+    if (object && postTarget == TargetObservableParent)
         object = object->observableObject();
 
     if (!object && document)
@@ -739,21 +739,21 @@
 
 void AXObjectCache::checkedStateChanged(Node* node)
 {
-    postNotification(node, AXObjectCache::AXCheckedStateChanged, true);
+    postNotification(node, AXObjectCache::AXCheckedStateChanged);
 }
 
 void AXObjectCache::selectedChildrenChanged(Node* node)
 {
     // postToElement is false so that you can pass in any child of an element and it will go up the parent tree
     // to find the container which should send out the notification.
-    postNotification(node, AXSelectedChildrenChanged, false);
+    postNotification(node, AXSelectedChildrenChanged, TargetObservableParent);
 }
 
 void AXObjectCache::selectedChildrenChanged(RenderObject* renderer)
 {
     // postToElement is false so that you can pass in any child of an element and it will go up the parent tree
     // to find the container which should send out the notification.
-    postNotification(renderer, AXSelectedChildrenChanged, false);
+    postNotification(renderer, AXSelectedChildrenChanged, TargetObservableParent);
 }
 
 void AXObjectCache::nodeTextChangeNotification(Node* node, AXTextChange textChange, unsigned offset, const String& text)
@@ -831,7 +831,7 @@
     if (attrName == aria_activedescendantAttr)
         handleActiveDescendantChanged(element);
     else if (attrName == aria_valuenowAttr || attrName == aria_valuetextAttr)
-        postNotification(element, AXObjectCache::AXValueChanged, true);
+        postNotification(element, AXObjectCache::AXValueChanged);
     else if (attrName == aria_labelAttr || attrName == aria_labeledbyAttr || attrName == aria_labelledbyAttr)
         textChanged(element);
     else if (attrName == aria_checkedAttr)
@@ -843,9 +843,9 @@
     else if (attrName == aria_hiddenAttr)
         childrenChanged(element->parentNode());
     else if (attrName == aria_invalidAttr)
-        postNotification(element, AXObjectCache::AXInvalidStatusChanged, true);
+        postNotification(element, AXObjectCache::AXInvalidStatusChanged);
     else
-        postNotification(element, AXObjectCache::AXAriaAttributeChanged, true);
+        postNotification(element, AXObjectCache::AXAriaAttributeChanged);
 }
 
 void AXObjectCache::labelChanged(Element* element)
@@ -739,21 +739,21 @@
 void AXObjectCache::selectedChildrenChanged(Node* node)
 {
-    // postToElement is false so that you can pass in any child of an element and it will go up the parent tree
+    // postTarget is TargetObservableParent so that you can pass in any child of an element and it will go up the parent tree
     // to find the container which should send out the notification.
@@ -739,21 +739,21 @@
 void AXObjectCache::selectedChildrenChanged(RenderObject* renderer)
 {
-    // postToElement is false so that you can pass in any child of an element and it will go up the parent tree
+    // postTarget is TargetObservableParent so that you can pass in any child of an element and it will go up the parent tree
     // to find the container which should send out the notification.

Modified: trunk/Source/WebCore/accessibility/AXObjectCache.h (156338 => 156339)

